ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 14 variants Io, External, Config, ChannelClosed, TaskCancelled, Join, Parse, BufferSizeLimit, ChecksumMismatch, MagicMismatch, OutOfRange, NoSpace, Closed, Recover,
}
ErrorKind is all kinds of Error of foyer.

Variants



Io

I/O error.



External

External error.



Config

Config error.



ChannelClosed

Channel closed.



TaskCancelled

Task cancelled.



Join

Join error.



Parse

Parse error.



BufferSizeLimit

Buffer size limit.

Not a real error.

Indicates that the buffer size has exceeded the limit and the caller may allocate a larger buffer and retry.



ChecksumMismatch

Checksum mismatch.



MagicMismatch

Magic mismatch.



OutOfRange

Out of range.



NoSpace

No sapce.



Closed

Closed.



Recover

Recover error.

Implementations

Source

impl ErrorKind

pub fn into_static(self) -> &'static str

Convert self into static str.