RangeBoundsExt

Trait RangeBoundsExt 

pub trait RangeBoundsExt<T: PartialOrd<T> + Add<Output = T> + Sub<Output = T> + Clone + Copy + Send + Sync + 'static + ZeroOne>: RangeBounds<T> {
    // Provided methods
    fn start(&self) -> Option<T> { ... }
    fn end(&self) -> Option<T> { ... }
    fn start_with_bound(&self, bound: T) -> T { ... }
    fn end_with_bound(&self, bound: T) -> T { ... }
    fn bounds(&self, range: Range<T>) -> Range<T> { ... }
    fn size(&self) -> Option<T> { ... }
    fn is_empty(&self) -> bool { ... }
    fn is_full(&self) -> bool { ... }
    fn map<F, R>(&self, f: F) -> (Bound<R>, Bound<R>)
       where F: Fn(&T) -> R { ... }
}
The range extensions.

Provided Methods

fn start(&self) -> Option<T>

Get the start bound of the range.

fn end(&self) -> Option<T>

Get the end bound of the range.

fn start_with_bound(&self, bound: T) -> T

Get the start bound with a default value of the range.

fn end_with_bound(&self, bound: T) -> T

Get the end bound with a default value of the range.

fn bounds(&self, range: Range<T>) -> Range<T>

Get the new range with the given range bounds.

fn size(&self) -> Option<T>

Get the range size.

fn is_empty(&self) -> bool

Check if the range is empty.

fn is_full(&self) -> bool

Check is the range is a full range.

fn map<F, R>(&self, f: F) -> (Bound<R>, Bound<R>)
where F: Fn(&T) -> R,

Map the range with the given method.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: PartialOrd<T> + Add<Output = T> + Sub<Output = T> + Clone + Copy + Send + Sync + 'static + ZeroOne, RB: RangeBounds<T>> RangeBoundsExt<T> for RB